@@ -1,5 +1,5 @@
 package POEx::WorkerPool::Role::WorkerPool::Worker;
-our $VERSION = '0.092520';
+our $VERSION = '0.092530';
 
 
 #ABSTRACT: A role that provides common semantics for Workers
@@ -184,7 +184,7 @@ role POEx::WorkerPool::Role::WorkerPool::Worker
             (
                 $self->pubsub_alias, +PXWP_JOB_ENQUEUED, 
                 worker_id => $self->ID,
-                job_id => $job->ID,
+                job => $job,
             );
         }
         else
@@ -207,7 +207,7 @@ role POEx::WorkerPool::Role::WorkerPool::Worker
                 (
                     $self->pubsub_alias, +PXWP_JOB_ENQUEUED, 
                     worker_id => $self->ID,
-                    job_id => $_->ID,
+                    job => $_,
                 );
             }
             @$jobs;
@@ -250,7 +250,7 @@ role POEx::WorkerPool::Role::WorkerPool::Worker
             (
                 $self->pubsub_alias, +PXWP_JOB_DEQUEUED, 
                 worker_id => $self->ID,
-                job_id => $job->ID,
+                job => $job,
             );
             
             $self->yield('_process_job', $job);
@@ -295,16 +295,16 @@ role POEx::WorkerPool::Role::WorkerPool::Worker
     {
         if($job_status->{type} eq +PXWP_JOB_COMPLETE)
         {
-            $self->_clear_in_process();
-            ${$self->_completed_jobs}++;
-
             $self->post
             (
                 $self->pubsub_alias, +PXWP_JOB_COMPLETE,
                 worker_id => $self->ID,
-                job_id => $job_status->{ID},
+                job => $self->_in_process,
                 msg => $job_status->{msg},
             );
+            
+            $self->_clear_in_process();
+            ${$self->_completed_jobs}++;
 
             $self->yield('_process_queue');
         }
@@ -314,25 +314,24 @@ role POEx::WorkerPool::Role::WorkerPool::Worker
             (
                 $self->pubsub_alias, +PXWP_JOB_PROGRESS,
                 worker_id => $self->ID,
-                job_id => $job_status->{ID},
+                job => $self->_in_process,
                 percent_complete => $job_status->{percent_complete},
                 msg => $job_status->{msg},
             );
         }
         elsif($job_status->{type} eq +PXWP_JOB_FAILED)
         {
-            $self->_clear_in_process();
-            
-            ${$self->_failed_jobs}++;
-            
             $self->post
             (
                 $self->pubsub_alias, +PXWP_JOB_FAILED,
                 worker_id => $self->ID,
-                job_id => $job_status->{ID},
+                job => $self->_in_process,
                 msg => $job_status->{msg},
             );
             
+            $self->_clear_in_process();
+            ${$self->_failed_jobs}++;
+            
             $self->yield('_process_queue');
         }
         elsif($job_status->{type} eq +PXWP_JOB_START)
@@ -341,7 +340,7 @@ role POEx::WorkerPool::Role::WorkerPool::Worker
             (
                 $self->pubsub_alias, +PXWP_JOB_START, 
                 worker_id => $self->ID,
-                job_id => $job_status->{ID},
+                job => $self->_in_process,
             );
         }
         else
@@ -372,7 +371,7 @@ POEx::WorkerPool::Role::WorkerPool::Worker - A role that provides common semanti
 
 =head1 VERSION
 
-version 0.092520
+version 0.092530
 
 =head1 ATTRIBUTES
 
@@ -526,7 +525,7 @@ success.
 
 Subscribers will need to have the following signature:
 
-    method handler (SessionID :$worker_id, Str $job_id) is Event
+    method handler (SessionID :$worker_id, DoesJob $job ) is Event
 
 
 
@@ -556,7 +555,7 @@ This private event is the queue processor. As jobs are dequeued for processing,
 +PXWP_JOB_DEQUEUED will be fired via PubSub. Subscribers will need the
 following signature:
 
-    method handler(SessionID :$worker_id, Str :$job_id) is Event
+    method handler(SessionID :$worker_id, DoesJob :$job) is Event
 
 Once the queue has been depleted +PXWP_STOP_PROCESSING will be fired via
 PubSub. Subscribers will need the following signature:
@@ -603,7 +602,7 @@ describes the potential events from the child and the actions taken
         +PXWP_JOB_COMPLETE
 
     PubSub Signature:
-        method handler(SessionID :$worker_id, Str :$job_id, Ref :$msg)
+        method handler(SessionID :$worker_id, DoesJob :$job, Ref :$msg)
 
     Notes:
         The :$msg argument will contain the output from the Job's execution
@@ -621,7 +620,7 @@ describes the potential events from the child and the actions taken
         method handler
         (
             SessionID :$worker_id, 
-            Str :$job_id, 
+            DoesJob :$job, 
             Int :$percent_complete,
             Ref :$msg,
         )
@@ -641,7 +640,7 @@ describes the potential events from the child and the actions taken
         +PXWP_JOB_FAILED
 
     PubSub Signature:
-        method handler(SessionID :$worker_id, Str :$job_id, Ref :$msg)
+        method handler(SessionID :$worker_id, DoesJob :$job, Ref :$msg)
 
     Notes:
         The :$msg argument will contain the exception generated from the Job
@@ -659,7 +658,7 @@ describes the potential events from the child and the actions taken
         method handler
         (
             SessionID :$worker_id, 
-            Str :$job_id, 
+            DoesJob :$job, 
         )
 
     Notes:
